@@ -88,6 +88,7 @@ class QGraphViz_Core(QWidget):
         self.hovered_Edge = None
         self.hovered_Edge_id = None
         self.current_pos = [0,0]
+        self.current_path = ""
         self.mouse_down=False
         self.min_cursor_edge_dist=min_cursor_edge_dist
         self.show_subgraphs=show_subgraphs
@@ -233,13 +234,16 @@ class QGraphViz_Core(QWidget):
 
     def load_file(self, filename):
         self.engine.graph = self.parser.parseFile(filename)
+        self.current_path = filename
         self.build()
         self.update()
 
     def loadAJson(self, filename):
         self.engine.graph = self.parser.fromJSON(filename)
+        self.current_path = filename
         self.build()
         self.update()
+        
 
     def save(self, filename):
         #BUGFIX : unhilight node before saving
